diff --git a/devstack/tempest-dsvm-lvm-rc b/devstack/tempest-dsvm-lvm-rc
index b4c5643b15..21272c8fc2 100644
--- a/devstack/tempest-dsvm-lvm-rc
+++ b/devstack/tempest-dsvm-lvm-rc
@@ -17,7 +17,7 @@
# It's used to configure which tempest tests actually get run. You can find
# the CI job configuration here:
#
-# http://git.openstack.org/cgit/openstack-infra/project-config/tree/jenkins/jobs/lvm.yaml
+# https://opendev.org/openstack/nova/src/branch/master/playbooks/legacy/nova-lvm/run.yaml
#
# Construct a regex to use when limiting scope of tempest
diff --git a/doc/source/admin/configuration/hypervisor-hyper-v.rst b/doc/source/admin/configuration/hypervisor-hyper-v.rst
index 0959c7cad1..9cdc6f86aa 100644
--- a/doc/source/admin/configuration/hypervisor-hyper-v.rst
+++ b/doc/source/admin/configuration/hypervisor-hyper-v.rst
@@ -318,7 +318,7 @@ Download the nova code
.. code-block:: none
- PS C:\> git.exe clone https://git.openstack.org/openstack/nova
+ PS C:\> git.exe clone https://opendev.org/openstack/nova
Install nova-compute service
----------------------------
diff --git a/doc/source/admin/configuration/schedulers.rst b/doc/source/admin/configuration/schedulers.rst
index 8d481e7ae1..15e4b5ff45 100644
--- a/doc/source/admin/configuration/schedulers.rst
+++ b/doc/source/admin/configuration/schedulers.rst
@@ -621,7 +621,7 @@ With the API, use the ``os:scheduler_hints`` key:
}
}
-.. _HostState: http://git.openstack.org/cgit/openstack/nova/tree/nova/scheduler/host_manager.py
+.. _HostState: https://opendev.org/openstack/nova/src/branch/master/nova/scheduler/host_manager.py
MetricsFilter
-------------
@@ -1539,4 +1539,4 @@ There are some rules associated with capability-defined traits.
5. Compute capability traits are standard traits defined in the `os-traits`_
library.
-.. _os-traits: http://git.openstack.org/cgit/openstack/os-traits/tree/os_traits/compute
+.. _os-traits: https://opendev.org/openstack/os-traits/src/branch/master/os_traits/compute
diff --git a/doc/source/admin/root-wrap-reference.rst b/doc/source/admin/root-wrap-reference.rst
index b25b8200e8..1a94d616c6 100644
--- a/doc/source/admin/root-wrap-reference.rst
+++ b/doc/source/admin/root-wrap-reference.rst
@@ -70,7 +70,7 @@ and is a Kilo release feature.
Including this workaround in your configuration file safeguards your
environment from issues that can impair root wrapper performance. Tool changes
that have impacted `Python Build Reasonableness (PBR)
-`__ for example, are a known
+`__ for example, are a known
issue that affects root wrapper performance.
To set up this workaround, configure the ``disable_rootwrap`` option in the
diff --git a/doc/source/contributor/api.rst b/doc/source/contributor/api.rst
index fce0d0e28f..773ca27ffb 100644
--- a/doc/source/contributor/api.rst
+++ b/doc/source/contributor/api.rst
@@ -52,7 +52,7 @@ A very basic controller of a v2.1 API::
# Defining support for other RESTFul methods based on resource.
-See `servers.py `_ for ref.
+See `servers.py `_ for ref.
All of the controller modules should live in the ``nova/api/openstack/compute`` directory.
@@ -100,7 +100,7 @@ A basic skeleton of URL mapping in routers.py::
.
)
-Complete routing list can be found in `routes.py `_.
+Complete routing list can be found in `routes.py `_.
Policy
@@ -308,7 +308,7 @@ The general steps for removing support for a deprecated REST API are:
the REST API routes that were removed along with any related configuration
options that were also removed.
-Here is an example of the above steps: https://review.openstack.org/567682/
+Here is an example of the above steps: https://review.opendev.org/567682/
-.. _route mapping: http://git.openstack.org/cgit/openstack/nova/tree/nova/api/openstack/compute/routes.py
+.. _route mapping: https://opendev.org/openstack/nova/src/branch/master/nova/api/openstack/compute/routes.py
.. _Obsolete APIs: https://developer.openstack.org/api-ref/compute/#obsolete-apis
diff --git a/doc/source/contributor/development-environment.rst b/doc/source/contributor/development-environment.rst
index 00b200b431..aa671fa910 100644
--- a/doc/source/contributor/development-environment.rst
+++ b/doc/source/contributor/development-environment.rst
@@ -71,7 +71,7 @@ Getting the code
Grab the code from git::
- git clone https://git.openstack.org/openstack/nova
+ git clone https://opendev.org/openstack/nova
cd nova
diff --git a/doc/source/contributor/how-to-get-involved.rst b/doc/source/contributor/how-to-get-involved.rst
index 902b6da6e5..9a03b90ed9 100644
--- a/doc/source/contributor/how-to-get-involved.rst
+++ b/doc/source/contributor/how-to-get-involved.rst
@@ -279,7 +279,7 @@ reviews:
- Maybe take a look at things you want to see merged, bug fixes and
features, or little code fixes
- Look for things that have been waiting a long time for a review:
- https://review.openstack.org/#/q/project:openstack/nova+status:open+age:2weeks
+ https://review.opendev.org/#/q/project:openstack/nova+status:open+age:2weeks
- If you get through the above lists, try other tools, such as:
http://status.openstack.org/reviews
diff --git a/doc/source/contributor/microversions.rst b/doc/source/contributor/microversions.rst
index e984bbfcc9..35df830986 100644
--- a/doc/source/contributor/microversions.rst
+++ b/doc/source/contributor/microversions.rst
@@ -44,7 +44,7 @@ responses from the server.
providing microversion ``2.27`` must use the older form.
For full details please read the `Kilo spec for microversions
-`_
+`_
and `Microversion Specification
`_.
@@ -226,7 +226,7 @@ A microversion is not needed in the following situation:
**Footnotes**
-.. [#f3] https://review.openstack.org/#/c/523194/
+.. [#f3] https://review.opendev.org/#/c/523194/
In Code
-------
diff --git a/doc/source/contributor/process.rst b/doc/source/contributor/process.rst
index 7c996166d1..aeb34d1147 100644
--- a/doc/source/contributor/process.rst
+++ b/doc/source/contributor/process.rst
@@ -332,7 +332,7 @@ entirely. A few tips:
Secondly, Nova is a big project, look for things that have been waiting
a long time for a review:
-https://review.openstack.org/#/q/project:openstack/nova+status:open+age:2weeks
+https://review.opendev.org/#/q/project:openstack/nova+status:open+age:2weeks
Eventually you should get some +1s from people working through the
review queue. Expect to get -1s as well. You can ask for reviews within
diff --git a/doc/source/contributor/ptl-guide.rst b/doc/source/contributor/ptl-guide.rst
index f5fa9305cf..8f9bad2381 100644
--- a/doc/source/contributor/ptl-guide.rst
+++ b/doc/source/contributor/ptl-guide.rst
@@ -205,13 +205,13 @@ RC
* https://wiki.openstack.org/wiki/RpcMajorVersionUpdates
- * Example: https://review.openstack.org/541035
+ * Example: https://review.opendev.org/541035
* “Merge latest translations" means translation patches
* Check for translations with:
- * https://review.openstack.org/#/q/status:open+project:openstack/nova+branch:master+topic:zanata/translations
+ * https://review.opendev.org/#/q/status:open+project:openstack/nova+branch:master+topic:zanata/translations
* Should NOT plan to have more than one RC if possible. RC2 should only happen
if there was a mistake and something was missed for RC, or a new regression
@@ -219,24 +219,24 @@ RC
* Do the RPC version aliases just before RC1 if no further RCs are planned.
Else do them at RC2. In the past, we used to update all service version
- aliases (example: https://review.openstack.org/230132) but since we really
+ aliases (example: https://review.opendev.org/230132) but since we really
only support compute being backlevel/old during a rolling upgrade, we only
need to update the compute service alias, see related IRC discussion:
http://eavesdrop.openstack.org/irclogs/%23openstack-nova/%23openstack-nova.2018-08-08.log.html#t2018-08-08T17:13:45
- * Example: https://review.openstack.org/642599
+ * Example: https://review.opendev.org/642599
* More detail on how version aliases work: https://docs.openstack.org/nova/latest/configuration/config.html#upgrade-levels
* Write the reno prelude for the release GA
- * Example: https://review.openstack.org/644412
+ * Example: https://review.opendev.org/644412
* Write the cycle-highlights in marketing-friendly sentences and propose to the
openstack/releases repo. Usually based on reno prelude but made more readable
and friendly
- * Example: https://review.openstack.org/644697
+ * Example: https://review.opendev.org/644697
Immediately after RC
--------------------
diff --git a/doc/source/contributor/testing/libvirt-numa.rst b/doc/source/contributor/testing/libvirt-numa.rst
index 9d6a5a30d3..f5827ac1d9 100644
--- a/doc/source/contributor/testing/libvirt-numa.rst
+++ b/doc/source/contributor/testing/libvirt-numa.rst
@@ -105,7 +105,7 @@ devstack repo:
.. code-block:: bash
$ sudo dnf install git
- $ git clone https://git.openstack.org/openstack-dev/devstack
+ $ git clone https://opendev.org/openstack/devstack
$ cd devstack
At this point a fairly standard devstack setup can be done with one exception:
diff --git a/doc/source/reference/notifications.rst b/doc/source/reference/notifications.rst
index ef81760114..76c113d2a7 100644
--- a/doc/source/reference/notifications.rst
+++ b/doc/source/reference/notifications.rst
@@ -368,5 +368,5 @@ Existing versioned notifications
.. versioned_notifications::
-.. [1] https://review.openstack.org/#/c/463001/
-.. [2] https://review.openstack.org/#/c/453077/
+.. [1] https://review.opendev.org/#/c/463001/
+.. [2] https://review.opendev.org/#/c/453077/
diff --git a/doc/source/reference/scheduler-hints-vs-flavor-extra-specs.rst b/doc/source/reference/scheduler-hints-vs-flavor-extra-specs.rst
index 76c11d92a1..209c8554e9 100644
--- a/doc/source/reference/scheduler-hints-vs-flavor-extra-specs.rst
+++ b/doc/source/reference/scheduler-hints-vs-flavor-extra-specs.rst
@@ -156,6 +156,6 @@ Footnotes
---------
.. [1] https://github.com/openstack/nova/blob/fbe6f77bc/nova/objects/image_meta.py#L225
-.. [2] https://review.openstack.org/#/c/440580/
+.. [2] https://review.opendev.org/#/c/440580/
.. [3] https://docs.openstack.org/nova/latest/user/flavors.html#extra-specs
.. [4] https://github.com/openstack/nova/blob/fbe6f77bc/nova/api/openstack/compute/schemas/scheduler_hints.py
diff --git a/doc/source/reference/upgrade-checks.rst b/doc/source/reference/upgrade-checks.rst
index 1126945f1c..8977cacbf1 100644
--- a/doc/source/reference/upgrade-checks.rst
+++ b/doc/source/reference/upgrade-checks.rst
@@ -34,7 +34,7 @@ prior to upgrading to Ocata.
Reference the `Ocata changes`_ for implementation details.
-.. _Ocata changes: https://review.openstack.org/#/q/topic:bp/resource-providers-scheduler-db-filters+status:merged+file:%255Enova/cmd/status.py
+.. _Ocata changes: https://review.opendev.org/#/q/topic:bp/resource-providers-scheduler-db-filters+status:merged+file:%255Enova/cmd/status.py
Guidelines
==========
@@ -95,9 +95,9 @@ Guidelines
* All checks should have an accompanying upgrade release note.
.. _grenade uses them: https://github.com/openstack-dev/grenade/blob/dc7f4a4ba/projects/60_nova/upgrade.sh#L96
-.. _openstack-ansible: https://review.openstack.org/#/c/575125/
-.. _in Rocky: https://review.openstack.org/#/c/581813/
-.. _blocker migration: https://review.openstack.org/#/c/289450/
+.. _openstack-ansible: https://review.opendev.org/#/c/575125/
+.. _in Rocky: https://review.opendev.org/#/c/581813/
+.. _blocker migration: https://review.opendev.org/#/c/289450/
Structure
=========
@@ -170,10 +170,10 @@ The results feed into a standard output for the checks:
.. note:: Long-term the framework for upgrade checks will come from the
`oslo.upgradecheck library`_.
-.. _initial change: https://review.openstack.org/#/c/411517/
-.. _cells v2 check: https://review.openstack.org/#/c/411525/
-.. _placement check: https://review.openstack.org/#/c/413250/
-.. _oslo.upgradecheck library: http://git.openstack.org/cgit/openstack/oslo.upgradecheck/
+.. _initial change: https://review.opendev.org/#/c/411517/
+.. _cells v2 check: https://review.opendev.org/#/c/411525/
+.. _placement check: https://review.opendev.org/#/c/413250/
+.. _oslo.upgradecheck library: http://opendev.org/openstack/oslo.upgradecheck/
Other
=====
diff --git a/doc/source/user/certificate-validation.rst b/doc/source/user/certificate-validation.rst
index a6cf440806..1c94d54116 100644
--- a/doc/source/user/certificate-validation.rst
+++ b/doc/source/user/certificate-validation.rst
@@ -29,7 +29,7 @@ create or rebuild commands, signature verification and certificate validation
will be performed, regardless of their settings in the Nova configurations.
See `Using Signature Verification`_ for details.
-.. _Cursive: http://git.openstack.org/cgit/openstack/cursive/
+.. _Cursive: http://opendev.org/x/cursive/
.. _Glance Image Signature Verification documentation: https://docs.openstack.org/glance/latest/user/signature.html
.. note::
@@ -138,8 +138,8 @@ Certificate validation is triggered by one of two ways:
2. A list of trusted certificate IDs is provided by one of three ways:
.. note:: The command line support is pending changes
- https://review.openstack.org/#/c/500396/ and
- https://review.openstack.org/#/c/501926/ to python-novaclient and
+ https://review.opendev.org/#/c/500396/ and
+ https://review.opendev.org/#/c/501926/ to python-novaclient and
python-openstackclient, respectively.
Environment Variable
diff --git a/doc/source/user/filter-scheduler.rst b/doc/source/user/filter-scheduler.rst
index d6a44bac3f..9e26dd30b0 100644
--- a/doc/source/user/filter-scheduler.rst
+++ b/doc/source/user/filter-scheduler.rst
@@ -307,7 +307,7 @@ The |NUMATopologyFilter| considers the NUMA topology that was specified for the
through the use of flavor extra_specs in combination with the image properties, as
described in detail in the related nova-spec document:
-* http://git.openstack.org/cgit/openstack/nova-specs/tree/specs/juno/implemented/virt-driver-numa-placement.rst
+* https://opendev.org/openstack/nova-specs/src/branch/master/specs/juno/implemented/virt-driver-numa-placement.rst
and try to match it with the topology exposed by the host, accounting for the
:oslo.config:option:`ram_allocation_ratio` and
diff --git a/doc/source/user/upgrade.rst b/doc/source/user/upgrade.rst
index d7e0124813..26373edd28 100644
--- a/doc/source/user/upgrade.rst
+++ b/doc/source/user/upgrade.rst
@@ -232,7 +232,7 @@ to ease upgrades:
* `Data migration example
`_
* `Data migration enforcement example
- `_
+ `_
(for sqlalchemy migrate/deprecated scripts):
#. The column can then be removed with a migration at the start of N+2.
diff --git a/etc/nova/logging_sample.conf b/etc/nova/logging_sample.conf
index 6841819242..985e0c0146 100644
--- a/etc/nova/logging_sample.conf
+++ b/etc/nova/logging_sample.conf
@@ -41,7 +41,7 @@ qualname = boto
# NOTE(mikal): suds is used by the vmware driver, removing this will
# cause many extraneous log lines for their tempest runs. Refer to
-# https://review.openstack.org/#/c/219225/ for details.
+# https://review.opendev.org/#/c/219225/ for details.
[logger_suds]
level = INFO
handlers = stderr
diff --git a/nova/api/ec2/cloud.py b/nova/api/ec2/cloud.py
index ea88ec0376..a43b5a10fc 100644
--- a/nova/api/ec2/cloud.py
+++ b/nova/api/ec2/cloud.py
@@ -27,5 +27,5 @@ class CloudController(object):
'The in tree EC2 API has been removed in Mitaka. '
'Please remove entries from api-paste.ini and use '
'the OpenStack ec2-api project '
- 'http://git.openstack.org/cgit/openstack/ec2-api/'
+ 'http://opendev.org/openstack/ec2-api/'
)
diff --git a/nova/conductor/manager.py b/nova/conductor/manager.py
index 26275e2ad8..a2ebc9a5bb 100644
--- a/nova/conductor/manager.py
+++ b/nova/conductor/manager.py
@@ -1290,7 +1290,7 @@ class ComputeTaskManager(base.Base):
This is a workaround as placement does not return which RP
fulfills which granular request group in the allocation candidate
request. There is a spec proposing a solution in placement:
- https://review.openstack.org/#/c/597601/
+ https://review.opendev.org/#/c/597601/
When that spec is implemented then this function can be
replaced with a simpler code that copies the group - RP
mapping out from the Selection object returned by the scheduler's
diff --git a/nova/objects/fields.py b/nova/objects/fields.py
index 439ce4b599..02056e21b0 100644
--- a/nova/objects/fields.py
+++ b/nova/objects/fields.py
@@ -1252,6 +1252,6 @@ class ListOfListsOfStringsField(fields.AutoTypedField):
# TODO(mriedem): Replace this with the version from oslo.versiondobjects
-# when https://review.openstack.org/#/c/634700/ is released.
+# when https://review.opendev.org/#/c/634700/ is released.
class ListOfUUIDField(AutoTypedField):
AUTO_TYPE = List(fields.UUID())
diff --git a/nova/objects/migrate_data.py b/nova/objects/migrate_data.py
index a3ca205cd0..29e6ba875b 100644
--- a/nova/objects/migrate_data.py
+++ b/nova/objects/migrate_data.py
@@ -54,7 +54,7 @@ class VIFMigrateData(obj_base.NovaObject):
# configuration reference for the destination host.
# NOTE(mriedem): This might not be sufficient based on how the
# destination host is configured for all vif types. See the note in
- # the libvirt driver here: https://review.openstack.org/#/c/551370/
+ # the libvirt driver here: https://review.opendev.org/#/c/551370/
# 29/nova/virt/libvirt/driver.py@7036
'source_vif': fields.Field(fields.NetworkVIFModel()),
}
diff --git a/nova/objects/request_spec.py b/nova/objects/request_spec.py
index c93da7d13c..a0cdf5faae 100644
--- a/nova/objects/request_spec.py
+++ b/nova/objects/request_spec.py
@@ -784,7 +784,7 @@ class RequestSpec(base.NovaObject):
This is a workaround as placement does not return which RP fulfills
which granular request group in the allocation candidate request. There
is a spec proposing a solution in placement:
- https://review.openstack.org/#/c/597601/
+ https://review.opendev.org/#/c/597601/
:param placement_allocations: The overall allocation made by the
scheduler for this RequestSpec
diff --git a/nova/tests/fixtures.py b/nova/tests/fixtures.py
index 164829b47b..fdb8662387 100644
--- a/nova/tests/fixtures.py
+++ b/nova/tests/fixtures.py
@@ -272,7 +272,7 @@ class DatabasePoisonFixture(fixtures.Fixture):
# to the code you're testing (for example: EventReporterStub)
#
# - peruse some of the other database poison warning fixes here:
- # https://review.openstack.org/#/q/topic:bug/1568414
+ # https://review.opendev.org/#/q/topic:bug/1568414
raise Exception('This test uses methods that set internal oslo_db '
'state, but it does not claim to use the database. '
'This will conflict with the setup of tests that '
diff --git a/nova/tests/functional/test_servers.py b/nova/tests/functional/test_servers.py
index 611c47e0a2..42b8c3478f 100644
--- a/nova/tests/functional/test_servers.py
+++ b/nova/tests/functional/test_servers.py
@@ -2755,7 +2755,7 @@ class ServerMovingTests(integrated_helpers.ProviderUsageBaseTestCase):
self.api.post_server_action(server['id'], post)
# NOTE(elod.illes): Should be changed to non-polling solution when
- # patch https://review.openstack.org/#/c/482629/ gets merged:
+ # patch https://review.opendev.org/#/c/482629/ gets merged:
# fake_notifier.wait_for_versioned_notifications(
# 'compute_task.rebuild_server')
self._wait_for_notification_event_type('compute_task.rebuild_server')
diff --git a/nova/tests/live_migration/hooks/ceph.sh b/nova/tests/live_migration/hooks/ceph.sh
index 6655bb38fe..3713dc88a4 100755
--- a/nova/tests/live_migration/hooks/ceph.sh
+++ b/nova/tests/live_migration/hooks/ceph.sh
@@ -1,7 +1,7 @@
#!/bin/bash
function prepare_ceph {
- git clone https://git.openstack.org/openstack/devstack-plugin-ceph /tmp/devstack-plugin-ceph
+ git clone https://opendev.org/openstack/devstack-plugin-ceph /tmp/devstack-plugin-ceph
source /tmp/devstack-plugin-ceph/devstack/settings
source /tmp/devstack-plugin-ceph/devstack/lib/ceph
install_ceph
@@ -10,7 +10,7 @@ function prepare_ceph {
$ANSIBLE subnodes --become -f 5 -i "$WORKSPACE/inventory" -m raw -a "executable=/bin/bash
source $BASE/new/devstack/functions
source $BASE/new/devstack/functions-common
- git clone https://git.openstack.org/openstack/devstack-plugin-ceph /tmp/devstack-plugin-ceph
+ git clone https://opendev.org/openstack/devstack-plugin-ceph /tmp/devstack-plugin-ceph
source /tmp/devstack-plugin-ceph/devstack/lib/ceph
install_ceph_remote
"
diff --git a/releasenotes/notes/records-list-skip-down-cells-84d995e75c77c041.yaml b/releasenotes/notes/records-list-skip-down-cells-84d995e75c77c041.yaml
index 8db45ac693..f5e7618713 100644
--- a/releasenotes/notes/records-list-skip-down-cells-84d995e75c77c041.yaml
+++ b/releasenotes/notes/records-list-skip-down-cells-84d995e75c77c041.yaml
@@ -12,5 +12,5 @@ other:
`blueprint handling-down-cell`_ where minimal constructs would be returned
for the down cell instances instead of raising 500s or skipping down cells.
- .. _change e3534d : https://review.openstack.org/#/q/I308b494ab07f6936bef94f4c9da45e9473e3534d
+ .. _change e3534d : https://review.opendev.org/#/q/I308b494ab07f6936bef94f4c9da45e9473e3534d
.. _blueprint handling-down-cell: https://blueprints.launchpad.net/nova/+spec/handling-down-cell
diff --git a/releasenotes/notes/remove-ec2-api-service-c17a35ed297355b8.yaml b/releasenotes/notes/remove-ec2-api-service-c17a35ed297355b8.yaml
index 9627d58298..77866b777d 100644
--- a/releasenotes/notes/remove-ec2-api-service-c17a35ed297355b8.yaml
+++ b/releasenotes/notes/remove-ec2-api-service-c17a35ed297355b8.yaml
@@ -3,5 +3,5 @@ other:
- Nova's EC2 API support which was deprecated in Kilo
(https://wiki.openstack.org/wiki/ReleaseNotes/Kilo#Upgrade_Notes_2) is
removed from Mitaka. This has been replaced by the new ec2-api project
- (http://git.openstack.org/cgit/openstack/ec2-api/).
+ (http://opendev.org/openstack/ec2-api/).
diff --git a/releasenotes/notes/remove_ec2_and_objectstore_api-4ccb539db1d171fa.yaml b/releasenotes/notes/remove_ec2_and_objectstore_api-4ccb539db1d171fa.yaml
index 67c5df643e..a3c3dc6036 100644
--- a/releasenotes/notes/remove_ec2_and_objectstore_api-4ccb539db1d171fa.yaml
+++ b/releasenotes/notes/remove_ec2_and_objectstore_api-4ccb539db1d171fa.yaml
@@ -4,4 +4,4 @@ upgrade:
was deprecated in Kilo
(https://wiki.openstack.org/wiki/ReleaseNotes/Kilo#Upgrade_Notes_2) has
been completely removed in Mitaka. This has been replaced by the new
- ec2-api project (http://git.openstack.org/cgit/openstack/ec2-api/).
\ No newline at end of file
+ ec2-api project (http://opendev.org/openstack/ec2-api/).
\ No newline at end of file
diff --git a/releasenotes/source/mitaka.rst b/releasenotes/source/mitaka.rst
index 43a3e6ea6c..b5eb0e9bde 100644
--- a/releasenotes/source/mitaka.rst
+++ b/releasenotes/source/mitaka.rst
@@ -497,7 +497,7 @@ Upgrade Notes
was deprecated in Kilo
(https://wiki.openstack.org/wiki/ReleaseNotes/Kilo#Upgrade_Notes_2) has
been completely removed in Mitaka. This has been replaced by the new
- ec2-api project (http://git.openstack.org/cgit/openstack/ec2-api/).
+ ec2-api project (http://opendev.org/openstack/ec2-api/).
.. warning:: Some installation tools (such as ``packstack``) hardcode the
value of ``enabled_apis`` in your nova.conf. While the defaults
@@ -712,6 +712,6 @@ Other Notes
.. releasenotes/notes/remove-ec2-api-service-c17a35ed297355b8.yaml @ b'eec7a55319b3f22949735227199ce49b851519b8'
-- Nova's EC2 API support which was deprecated in Kilo (https://wiki.openstack.org/wiki/ReleaseNotes/Kilo#Upgrade_Notes_2) is removed from Mitaka. This has been replaced by the new ec2-api project (http://git.openstack.org/cgit/openstack/ec2-api/).
+- Nova's EC2 API support which was deprecated in Kilo (https://wiki.openstack.org/wiki/ReleaseNotes/Kilo#Upgrade_Notes_2) is removed from Mitaka. This has been replaced by the new ec2-api project (http://opendev.org/openstack/ec2-api/).
diff --git a/tools/abandon_old_reviews.sh b/tools/abandon_old_reviews.sh
index c95b95ae4f..89af0e983f 100755
--- a/tools/abandon_old_reviews.sh
+++ b/tools/abandon_old_reviews.sh
@@ -15,9 +15,9 @@
#
#
# before you run this modify your .ssh/config to create a
-# review.openstack.org entry:
+# review.opendev.org entry:
#
-# Host review.openstack.org
+# Host review.opendev.org
# User
# Port 29418
#
@@ -33,13 +33,13 @@ function abandon_review {
shift
local msg=$@
echo "Abandoning $gitid"
- # echo ssh review.openstack.org gerrit review $gitid --abandon --message \"$msg\"
- ssh review.openstack.org gerrit review $gitid --abandon --message \"$msg\"
+ # echo ssh review.opendev.org gerrit review $gitid --abandon --message \"$msg\"
+ ssh review.opendev.org gerrit review $gitid --abandon --message \"$msg\"
}
PROJECTS="(project:openstack/nova OR project:openstack/python-novaclient)"
-blocked_reviews=$(ssh review.openstack.org "gerrit query --current-patch-set --format json $PROJECTS status:open age:4w label:Code-Review<=-2" | jq .currentPatchSet.revision | grep -v null | sed 's/"//g')
+blocked_reviews=$(ssh review.opendev.org "gerrit query --current-patch-set --format json $PROJECTS status:open age:4w label:Code-Review<=-2" | jq .currentPatchSet.revision | grep -v null | sed 's/"//g')
blocked_msg=$(cat < 4w with no changes and Jenkins has -1ed
-failing_reviews=$(ssh review.openstack.org "gerrit query --current-patch-set --format json $PROJECTS status:open age:4w NOT label:Verified>=1,jenkins" | jq .currentPatchSet.revision | grep -v null | sed 's/"//g')
+failing_reviews=$(ssh review.opendev.org "gerrit query --current-patch-set --format json $PROJECTS status:open age:4w NOT label:Verified>=1,jenkins" | jq .currentPatchSet.revision | grep -v null | sed 's/"//g')
failing_msg=$(cat <